<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class AdminController extends Controller
{
    // Muestra el formulario de login
    public function showLoginForm()
    {
        return view('admin.login');
    }

    // Procesa el login
    public function login(Request $request)
    {
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ]);

        $user = User::where('email', $request->email)->first();

        if ($user && Hash::check($request->password, $user->password)) {
            session([
                'user_id' => $user->id,
                'is_admin' => $user->is_admin,
            ]);

            return redirect()->route('admin.dashboard');
        }

        return back()->withErrors(['login_error' => 'Credenciales incorrectas.']);
    }

    // Muestra el panel de administración
    public function dashboard()
    {
        if (!session('user_id')) {
            return redirect()->route('admin.login');
        }

        $users = User::where('is_admin', false)->get();
        $isAdmin = session('is_admin', false);

        return view('admin.dashboard', compact('users', 'isAdmin'));
    }

    // Muestra el formulario de registro de usuarios
    public function showRegisterForm()
    {
        if (!session('user_id') || !session('is_admin')) {
            return redirect()->route('admin.dashboard')
                ->withErrors(['permission_error' => 'No tienes permiso para registrar usuarios.']);
        }

        return view('admin.register');
    }

    // Procesa el registro de un nuevo usuario
    public function register(Request $request)
    {
        if (!session('is_admin')) {
            return redirect()->route('admin.dashboard')
                ->withErrors(['permission_error' => 'No tienes permiso para registrar usuarios.']);
        }

        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6',
        ]);

        User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password),
            'is_admin' => false,
            'ing_iglesia' => $request->ing_iglesia,
        ]);

        return redirect()->route('admin.dashboard')->with('success', 'Usuario registrado con éxito.');
    }

    // Cerrar sesión
    public function logout()
    {
        session()->forget(['user_id', 'is_admin']);
        return redirect()->route('admin.login');
    }
}

